import axios from 'axios'
import { Message, MessageBox } from 'element-ui'
import store from '../store'
import { getToken } from '@/utils/auth'
import cleanDeep from 'clean-deep'
import qs from 'qs'

// 创建axios实例
const service = axios.create({
  baseURL: process.env.BASE_API, // api的base_url
  timeout: 30000 // 请求超时时间
})

// request拦截器
service.interceptors.request.use(config => {
  let tocken =getToken()
  if (tocken) {
    config.headers['Authorization'] = tocken // 让每个请求携带自定义token 请根据实际情况自行修改
  }
  if(config.url.indexOf('/api-mall-admin')== -1){
    if(config.url.indexOf('/api-admin')== -1 && config.url.indexOf('/api-auth')== -1){
      config.url = '/api-mall-admin'+config.url
    }
  }
  // 是否进行数据过滤
  const noCleanDeep = config.noCleanDeep || false
  if (config.requestType === 'form') {
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded'
    config.data = qs.stringify(
      noCleanDeep ? config.data : cleanDeep(config.data)
    )
  } else if (config.requestType === 'multipart') {
    config.headers['Content-Type'] = 'multipart/form-data'
  } else {
    config.data = noCleanDeep ? config.data : cleanDeep(config.data)
  }
  config.params = noCleanDeep
    ? qs.stringify(config.data)
    : cleanDeep(config.params)
  return config
}, error => {
  // Do something with request error// for debug
  Promise.reject(error)
})

// respone拦截器
service.interceptors.response.use(
  response => {
  /**
  * code为非200是抛错 可结合自己业务进行修改
  */

    const res = response.data
    if (res.code !== 200) {
      Message({
        message: res.msg||res.message,
        type: 'error',
        duration: 3 * 1000
      })

      // 401:未登录;
      if (res.code === 401 || res.code === 403) {
        console.log('401/403')
        location = window.location.origin;

        // MessageBox.confirm('登录过期请重新登录', '确定登出', {
        //   confirmButtonText: '重新登录',
        //   cancelButtonText: '取消',
        //   type: 'warning'
        // }).then(() => {
        //   store.dispatch('FedLogOut').then(() => {
        //      location.reload()// 为了重新实例化vue-router对象 避免bug
        //     location.href = window.location.hostname;
        //   })

        // })
      }
      return Promise.reject('error')
    } else {
      return response.data
    }
  },
  error => {
    console.log('err' + error)// for debug
    Message({
      message: error.message,
      type: 'error',
      duration: 3 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
